import 'package:fluent_ui/fluent_ui.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:window_manager/window_manager.dart';

void main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await windowManager.ensureInitialized();

  WindowOptions windowOptions = WindowOptions(
    title: "Flutter Desktop Template",
    size: Size(800, 600),
    center: true,
    backgroundColor: Colors.transparent,
    skipTaskbar: false,
    titleBarStyle: TitleBarStyle.normal,
  );
  windowManager.waitUntilReadyToShow(windowOptions, () async {
    await windowManager.show();
    await windowManager.focus();
  });

  runApp(ProviderScope(child: const MyApp()));
}

class MyApp extends HookConsumerWidget {
  const MyApp({super.key});

  @override
  Widget build(Object context, WidgetRef ref) {
    final conter = useState(0);
    return FluentApp(
      debugShowCheckedModeBanner: true,
      locale: Locale('zh', 'CN'),

      home: Container(
        color: Colors.white,
        alignment: Alignment.center,

        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Text("${conter.value}"),
            Button(
              child: const Text("Click me"),
              onPressed: () => {conter.value++},
            ),
          ],
        ),
      ),
    );
  }
}
